<?php
// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Creates class for send emails
class McisoeSendEmails
{
    // Set email defaults
    public function mcisoe_send_email()
    {
        // Trigger on paid orders
        add_action('woocommerce_order_status_on-hold_to_processing_notification', array($this, 'trigger'));
        add_action('woocommerce_order_status_pending_to_processing_notification', array($this, 'trigger'));
        add_action('woocommerce_order_status_failed_to_processing_notification', array($this, 'trigger'));
    }
    //================================================================
    // Defines the Trigger function
    //================================================================
    // Define la función Trigger
    public function trigger($order_id)
    {
        require 'get-db-mcisoe.php'; // include data of DB  // Incluir los datos de la Base de datos

        $mcisoe_auth_premium = get_option('mcisoe_auth_premium');

        //===============================================
        // GET DETAILS
        //===============================================
        // Get $order object from order ID
        $order = wc_get_order($order_id);

        // abort if no order ID is present  // Aborta si no hay ID de pedido
        if (!$order_id) {
            return;
        }

        //  START Get Premium fields /////////////////////////////////////////////////////////
        if ($mcisoe_auth_premium) { // Check password premium
            if ($get_show_order_number == '1') {
                $order_number        = $order->get_id();
                $header_order_number = __("Our order number: ", "supplier-order-email");
                $header_order_number .= $order_number;
            }

            $header_color = $get_header_color;
            $header_email = '<h1 style="background-color:' . $header_color . '; color:#ffffff; text-align:center; padding:20px 15px; font-size:25px">' .
                get_bloginfo('name', 'display') .
                '</h1>';

            if ($get_show_customer_email == 1) {
                $customer_email = sanitize_email($order->get_billing_email());
            } else {
                $customer_email = null;
            }

            if ($order->get_customer_note() && $order->get_customer_note() != "" && $get_show_notes == 1 && $get_hide_customer != 1) {
                $customer_note = '<strong>' . __("Note:", "supplier-order-email") . '</strong>' . " " . sanitize_text_field($order->get_customer_note());
                $customer_note .= '<br>' . '-------------------------------' . '<br>';
            } else {
                $customer_note = "";
            }

            //Get order custom fields //////////////////////////////////////////////////////////
            //Delivery date:
            if (get_post_meta($order_id, '_delivery_date', true)) {
                $delivery_date = '<strong>' . __("Delivery date:", "supplier-order-email") . '</strong>' . " " . sanitize_text_field(get_post_meta($order_id, '_delivery_date', true)) . '<br><br>';
            }
        }

        isset($header_email) ? $header_email = $header_email : $header_email = "";

        // END Get Premium fields ////////////////////////////////////////////////////////////

        // Get Shipping Customer data and email introduction  // Obtiene los datos de envío del comprador y la introducción del email
        $intro = sanitize_text_field($get_intro) . '<br><br>';
        if ($get_intro == "") {
            $intro = __("Hello, we need you to send this order directly to the end customer without valued documents. Thank you.", "supplier-order-email") . '<br><br>';
        }

        //  START Get Premium fields /////////////////////////////////////////////////////////

        if (isset($get_hide_customer) && $get_hide_customer == 1) {
            $header_shipping_address    = "";
            $formatted_shipping_address = "";
            $phone_shipping_address     = "";
            $customer_email             = "";
            $customer_note              = "";

            // END Get Premium fields ////////////////////////////////////////////////////////////
        } else {
            $header_shipping_address = __("Send the order to:", "supplier-order-email");

            if ($get_replace_address == 1 && empty($order->get_shipping_address_1())) { // if not have shipping address, use billing address
                $shipping_address_1         = sanitize_text_field($order->get_billing_address_1());
                $formatted_shipping_address = $order->get_formatted_billing_address();
                $phone_shipping_address     = '<br>' . sanitize_text_field($order->get_billing_phone());
                $billing_email              = '<br>' . $customer_email . '<br><br>';
            } else {
                $shipping_address_1         = sanitize_text_field($order->get_shipping_address_1());
                $formatted_shipping_address = $order->get_formatted_shipping_address();
                if (!empty($order->get_shipping_address_1())) {
                    if ($order->get_shipping_phone() != null && !empty($order->get_shipping_phone())) {
                        $phone_shipping_address = '<br>' . sanitize_text_field($order->get_shipping_phone());
                    } else {
                        $phone_shipping_address = '<br>' . sanitize_text_field($order->get_billing_phone());
                    }
                    if (isset($customer_email)) {
                        $billing_email = '<br>' . $customer_email . '<br><br>';
                    } else {
                        $billing_email = '<br>';
                    }
                } else {
                    $empty_address_advice = __('The shipping address are empty because the order has no address. Contact us to solve it.', 'supplier-order-email');
                }
            }
        }

        $header_items = __("Products to send:", "supplier-order-email");

        // Access to order items  // Accede a los items del pedido
        if ($order) {
            $items = $order->get_items(); // Get items of Order

            // Get supplier array  // Obtiene el array de los proveedores
            $suppliers_emails = $wpdb->get_results("SELECT id, supplier_name, supplier_email FROM " . esc_sql($tabla_mcisoe_suppliers) . " WHERE supplier_name != ''");

            // Foreach for send email several times  // Bucle para enviar email varias veces
            foreach ($suppliers_emails as $row) {
                $supplier_name  = $row->supplier_name;
                $supplier_email = $row->supplier_email;

                // Get and print lines of item  // Obtener e imprimir líneas de items
                if (!empty($supplier_name) && !empty($supplier_email)) {
                    esc_html_e("Products:", "supplier-order-email");
                }

                // Initzialitze the print_items value  // Inicializa el valor print_items
                $print_items = "";
                // Initzialitze $order_total value
                $order_total = 0;

                foreach ($items as $item) { // Loop through ordered items // Bucle items

                    $separator   = " --> ";
                    $product_qty = sanitize_text_field($item['qty']); // Get Quantity  // Obtener cantidad
                    $product_qty = $product_qty . " " . __('unit/s', 'supplier-order-email');

                    // Get SKU  // Obtener SKU
                    $product_complete = $item->get_product(); // Get complete product from item

                    $product_sku = sanitize_text_field($product_complete->get_sku()); // Get sku from product  // Obtener SKU
                    if (!empty($product_sku)) {
                        $product_sku = $separator . "Ref: " . $product_sku;
                    } else {
                        $product_sku = "";
                    }

                    $product_name = sanitize_text_field($item['name']); // Get name  // Obtener nombre
                    $product_name = $separator . $product_name;

                    // START Premium product Fields////////////////////////////////////////////////////////////////////////
                    if ($mcisoe_auth_premium) { // Check password premium

                        // Get Attributes and attributes in variations
                        $attributes = null;
                        // load meta data - product attributes
                        foreach ($item->get_meta_data() as $metaData) {
                            $separator = " --> ";

                            $attribute = $metaData->get_data();

                            // Get and prepare attributes
                            $clave = sanitize_text_field($attribute['key']);
                            $clave = str_replace('pa_', '', $clave);
                            $clave = ucfirst($clave); // First letter Uppercase
                            $pos   = strpos($clave, '_'); // Search "_" at start of string

                            $valor = sanitize_text_field($attribute['value']);

                            // Set variable for attributes if string not start by "_"
                            if ($pos < 1 && !is_numeric($pos)) {
                                $attributes .= $separator . $clave . ": " . $valor;
                            }
                        } //end foreach get attributes

                        if ($get_show_ean == '1') {
                            $label_ean   = __('EAN:', 'supplier-order-email');
                            $product_ean = sanitize_text_field($product_complete->get_meta('_wpm_gtin_code'));
                            if (!empty($product_ean)) {
                                $product_ean = $separator . $label_ean . $product_ean;
                            } else {
                                $product_ean = "";
                            }
                        }

                        if ($get_show_price_items == '1') {
                            $label_price_item = __('Price:', 'supplier-order-email');
                            $price_item       = $item['total'] + $item['total_tax'];
                            $price_item       = round($price_item, 2);
                            if (!empty($item['total'])) {
                                $price_item = $separator . $label_price_item . " " . $price_item . " " . get_woocommerce_currency_symbol() . " ";
                            } else {
                                $price_item = "";
                            }
                        }
                        ////////////////////////////////////////////////
                        //Get WooTours labels & other item product custom fields //Obtiene las etiquetas de WooTours y otros campos de producto personalizados
                        if ($get_show_product_meta == '1') {
                            $product_id            = $item->get_product_id();
                            $product               = wc_get_product($product_id);
                            $product_custom_fields = get_post_custom($product_id);

                            $wt_date_label   = sanitize_text_field($product_custom_fields['wt_date_label'][0]);
                            $wt_adult_label  = sanitize_text_field($product_custom_fields['wt_adult_label'][0]);
                            $wt_child_label  = sanitize_text_field($product_custom_fields['wt_child_label'][0]);
                            $wt_infant_label = sanitize_text_field($product_custom_fields['wt_infant_label'][0]);

                            // Get meta_items for product line // Obtener meta_items para la línea de producto
                            $product_meta_items = "";
                            $meta_items         = $item->get_formatted_meta_data('', false);

                            if ($meta_items && !empty($meta_items)) {

                                $product_meta_items .= '<br>-------------------------------<br>';
                                foreach ($meta_items as $meta_item) {

                                    if ($meta_item->key !== '_metadate') {

                                        $product_meta_items .= '<b>' . sanitize_text_field($meta_item->display_key) . ':</b> ' . sanitize_text_field($meta_item->display_value) . '<br>';
                                    }
                                }

                                //Write WooTours labels
                                $product_meta_items = str_replace('_date', $wt_date_label, $product_meta_items);
                                $product_meta_items = str_replace('_adult', $wt_adult_label, $product_meta_items);
                                $product_meta_items = str_replace('_child', $wt_child_label, $product_meta_items);
                                $product_meta_items = str_replace('_infant', $wt_infant_label, $product_meta_items);
                            } //end if meta_items
                        }
                    } // End if password verify

                    // END Premium product Fields////////////////////////////////////////////////////////////////////////

                    global $product; // Get supplier primary taxonomy if exists (Yoast SEO)  // Obtener la taxonomía primaria del proveedor si existe (Yoast SEO)
                    $taxonomy = 'supplier';

                    //Condition if Yoast SEO plugin is active //Condición si el plugin Yoast SEO está activo
                    if (!function_exists('is_plugin_active')) {
                        include_once ABSPATH . 'wp-admin/includes/plugin.php';
                    }
                    if (is_plugin_active('wordpress-seo/wp-seo.php')) {
                        $primary_cat_id = yoast_get_primary_term_id($taxonomy, $item->get_product_id());
                    } else {
                        $primary_cat_id = false;
                    }

                    if (isset($primary_cat_id) && is_plugin_active('wordpress-seo/wp-seo.php') && $primary_cat_id !== false && $primary_cat_id !== "") {

                        $primary_cat      = get_term($primary_cat_id, $taxonomy);
                        $primary_cat_name = $primary_cat->name;
                        $supplier         = sanitize_text_field(strip_tags($primary_cat_name)); // Strip html tags  // Quitar etiquetas html

                    } else {
                        //If Yoast is inactive or not has primary category
                        $item_taxonomy_terms = get_the_terms($item->get_product_id(), 'supplier');
                        $first_cat_id        = ($item_taxonomy_terms[0]->name);
                        $supplier            = sanitize_text_field(strip_tags($first_cat_id)); // Strip html tags  // Quitar etiquetas html
                    }

                    // Print product item line
                    if ($supplier_name == $supplier) { // Print product line if supplier is this  // Imprime línea de producto si es este el proveedor

                        $print_items .= $product_qty . $product_sku . $product_name . $attributes . $price_item . $product_ean . " (" . sanitize_text_field($supplier) . ")" . $product_meta_items . '<br>';

                        // START Premium prices fields //////////////////////////////////////////////////////////////////
                        // Calculate Order total
                        if ($get_show_order_total == '1') {
                            $order_total = $order_total + ($item['total'] + $item['total_tax']); // Sum line item value to $order_total
                        } else {
                            $order_total = "";
                        }
                        // END Premium prices fields //////////////////////////////////////////////////////////////////

                        $print_items .= '-------------------------------' . '<br>';
                    } // end if
                } // end Foreach $items

                // START Premium prices fields //////////////////////////////////////////////////////////////////
                if ($mcisoe_auth_premium) { // Check password premium
                    // Add line $order_total
                    if ($get_show_order_total == '1' && $order_total > 0) {
                        $order_total = "<br><br>" . __('Total Order price:', 'supplier-order-email') . " " . round($order_total, 2) . " " . get_woocommerce_currency_symbol();
                        $print_items .= $order_total;
                    }
                }
                // END Premium prices fields //////////////////////////////////////////////////////////////////

                //===============================================
                // Defines email variables  // Define las variables para el email

                $to      = sanitize_email($supplier_email);
                $subject = sanitize_text_field($get_subject);
                if ($subject == "") {
                    $subject = __('New order to send', 'supplier-order-email');
                }
                // START Premium prices fields //////////////////////////////////////////////////////////////////
                if ($mcisoe_auth_premium) {
                    $subject = str_replace('{order_number}', esc_html($order->get_id()), $subject); //Substitute variables in subject
                }
                // END Premium prices fields //////////////////////////////////////////////////////////////////
                $message =
                    $header_email .
                    $intro .
                    "<h4>" . esc_html($header_order_number) . "</h4>" .
                    "<h4>" . esc_html($header_shipping_address) . "</h4>" .
                    $formatted_shipping_address .
                    $phone_shipping_address .
                    $billing_email .
                    $delivery_date .
                    $customer_note .
                    $empty_address_advice .
                    "<h4>" . esc_html($header_items) . "</h4>" .
                    $print_items . "<br>";
                $headers[] = 'Content-Type: text/html';
                $headers[] = 'From: ' . sanitize_text_field(get_bloginfo()) . ' <' . sanitize_text_field(get_option('admin_email')) . '>';

                // Send email  // Envía el correo electrónico
                if (!empty($supplier_name) && !empty($supplier_email) && !empty($print_items)) {
                    wp_mail($to, $subject, $message, $headers);
                }
            } // end foreach

        } // end if

        return true;
    } // end Trigger

} // end class McisoeSendEmails
